#!/bin/bash

#############################################################################
# PUSHDOC de masse
#  Auteur : Jason Maire - (c)2014 Adullact Projet
#
# Description : Ce script fait de l'injection de masse, basé sur le parcours
# d'une arborescence d'un répertoire de base (récupération dynamique de la 
# typologie basée sur deux niveaux pour récupérer le nom des types (niveau 1)
# et le nom des sous-types (niveau 2), tel que :
#  REPERTOIRE_SOURCE/_type_/_sous-type_/DOSSIER_DEPOT
#
# Parametres optionnels (pour surcharger params par defaut ci-dessous:
# - REPERTOIRE_SOURCE (1er paramètre ou si absent le repertoire indiqué dans
#    ce script sur la variable REPERTOIRE_SOURCE)
# - EXTENSION (2e paramètre, si absent l'extension indiquée dans ce script
#    sur la variable EXTENSION)
# - EMETTEUR (3e paramètre permet de surcharger l'adresse email de l'émetteur 
#
# Il va ensuite récupérer tous les fichiers avec une extension particulière
# et les envoyer dans le parapheur avec le type/sous-type correspondant au
# dossier dans lequel le fichier se trouve.
# Si sous-répertoires, alors les documents ainsi contenus se décomposent en
# pièce principale + annexes. La pièce principale se reconnait avec son
# préfixe défini dans la variable PREFIXE_DOC ("BDC_")
#############################################################################

JAVA="java"
LOG_FILE="./pushdoc.log"
JAR="./pushdociparapheur-1.4.jar"
FICHIER_CONF="./conf.cf"
REPERTOIRE_SOURCE="/tmp/TOTO"
DOSSIER_DEPOT="DEPOT"
PREFIXE_DOC="BDC_"
EXTENSION="pdf"
EMETTEUR="toto@titi.com"

## Si le repertoire source renseigné en paramètre existe : on surcharge 
if [[ ( $# > 0 ) && ( -d "$1" ) ]]
then
	REPERTOIRE_SOURCE=$1
fi

## Si l'extension renseignée en paramètre n'est pas vide : on surcharge 
if [[ ( $# > 1 ) && ( -n $2 ) ]]; then
	EXTENSION=$2
fi

## Si l'adresse électronique renseignée en paramètre n'est pas vide : on surcharge 
if [[ ( $# > 2 ) && ( -n $3 ) ]]; then
	EMETTEUR=$3
fi

# Vérification des prérequis
if [[ !( -f "$FICHIER_CONF" ) ]]
then
        echo "Fichier de configuration introuvable : \"$FICHIER_CONF\""
        exit 1
fi

if [[ !( -f "$JAR" ) ]]
then
        echo "JAR introuvable : \"$JAR\""
        exit 1
fi

DATE=`date +%Y-%m-%d:%H:%M:%S`
echo "$DATE - DEBUT DU TRAITEMENT" >> $LOG_FILE
for REPERTOIRE_TYPE in "$REPERTOIRE_SOURCE"/* # On parcourt les types
do
	if [[ -d "$REPERTOIRE_TYPE" ]] # Si c'est un dossier, on continue
	then
		TYPE=$(basename "$REPERTOIRE_TYPE")
		echo "Récupération du type : $TYPE"

		for REPERTOIRE_SOUSTYPE in "$REPERTOIRE_TYPE"/* # On parcours les sous-types
		do
			
			if [[ -d "$REPERTOIRE_SOUSTYPE" ]] # Si c'est un dossier, on continue
			then
				SOUSTYPE=$(basename "$REPERTOIRE_SOUSTYPE")
				echo "Récupération du sous-type : $SOUSTYPE"

				for CHEMIN_FICHIER in "$REPERTOIRE_SOUSTYPE"/"$DOSSIER_DEPOT"/*.$EXTENSION # On parcourt les fichiers
				do
					if [[ -f "$CHEMIN_FICHIER" ]] # Si c'est un fichier qui existe
					then

						FICHIER=$(basename "$CHEMIN_FICHIER") # avec l'extension
						#extension="${FICHIER##*.}"
						NOM_FICHIER="${FICHIER%.*}" # sans l'extension
					
						DATE=`date +%Y-%m-%d:%H:%M:%S`
						echo "$DATE - Envoi du fichier $FICHIER avec typologie : $TYPE / $SOUSTYPE" >> $LOG_FILE

						# On envoie le fichier au i-Parapheur
						RETOUR=`"$JAVA" -jar "$JAR" --type "$TYPE" --sousType "$SOUSTYPE" --documentPrincipal "$CHEMIN_FICHIER" --visuelPdf "$CHEMIN_FICHIER" --nomDocumentPrincipal "$FICHIER" --visibilite CONFIDENTIEL --id "$NOM_FICHIER" --email $EMETTEUR --config "$FICHIER_CONF"`
					
						DATE=`date +%Y-%m-%d:%H:%M:%S`
						echo "$DATE - Retour du parapheur : $RETOUR" >> $LOG_FILE
						if [[ $RETOUR == "Dossier $NOM_FICHIER soumis dans le circuit" ]] # Si le dossier est bien créé, on supprime le fichier
						then
							DATE=`date +%Y-%m-%d:%H:%M:%S`
							echo "$DATE - Suppression du fichier : $FICHIER" >> $LOG_FILE
							rm -f "$CHEMIN_FICHIER"

						fi
					fi
				done
				
				for CHEMIN_REP in "$REPERTOIRE_SOUSTYPE"/"$DOSSIER_DEPOT"/*	 # On parcourt les repertoires
				do
					if [[ -d "$CHEMIN_REP" ]]	# si c'est un dossier on traite
					then
						FICHIER=""
						ANNEXES="{"
						CHEMIN_FICHIER=""
						j=0
						for CHEMIN_CANDIDAT in "$CHEMIN_REP"/*.$EXTENSION # On parcourt les fichiers
						do
							CANDIDAT=$(basename "$CHEMIN_CANDIDAT") # avec l'extension

							## if [[ $CANDIDAT == BDC_* ]]
							if [[ $CANDIDAT == "$PREFIXE_DOC"* ]]
							then
								CHEMIN_FICHIER=$CHEMIN_CANDIDAT
								FICHIER=$CANDIDAT
							else
								((j++))
								if [[ $j > 1 ]] 
								then
									ANNEXES="$ANNEXES , "
								fi
								ANNEXES="$ANNEXES \"$j\":\"$CANDIDAT\""
							fi
						done
						ANNEXES="$ANNEXES }"
						NOM_FICHIER="${FICHIER%.*}" # sans l'extension
						
						DATE=`date +%Y-%m-%d:%H:%M:%S`
						echo "$DATE - Envoi du fichier $FICHIER (et annexes $ANNEXES) avec typologie : $TYPE / $SOUSTYPE" >> $LOG_FILE

						# On envoie le fichier au i-Parapheur
						RETOUR=`"$JAVA" -jar "$JAR" --type "$TYPE" --sousType "$SOUSTYPE" --documentPrincipal "$CHEMIN_FICHIER" --visuelPdf "$CHEMIN_FICHIER" --nomDocumentPrincipal "$FICHIER" --visibilite CONFIDENTIEL --id "$NOM_FICHIER" --email $EMETTEUR --annexes "$ANNEXES" --config "$FICHIER_CONF"`

						DATE=`date +%Y-%m-%d:%H:%M:%S`
						echo "$DATE - Retour du parapheur : $RETOUR" >> $LOG_FILE
						if [[ $RETOUR == "Dossier $NOM_FICHIER soumis dans le circuit" ]] # Si le dossier est bien créé, on supprime le fichier
						then
							DATE=`date +%Y-%m-%d:%H:%M:%S`
							echo "$DATE - Suppression du répertoire relatif à : $FICHIER" >> $LOG_FILE
							rm -rf "$CHEMIN_REP"

						fi

					fi
				done

			fi
		done
	fi
done
DATE=`date +%Y-%m-%d:%H:%M:%S`
echo "$DATE - FIN DU TRAITEMENT" >> $LOG_FILE

